@@ -23,8 +23,14 @@ create_weighting <- function(dataset, ...){
 
   # data set content: Y, w, gps, counter, row_index, c
 
+  if (sum(!is.element(c("Y","w","gps","counter","row_index"),
+                      colnames(dataset)))> 0){
+    stop("Dataset does not include all required columns.")
+  }
+
   Nm <- compute_density(dataset[["w"]], dataset[["w"]])
   ipw <- Nm / (dataset[["gps"]])
-  return(data.table(cbind(dataset[,c("Y","w","gps","counter","row_index")],
+  return(data.table::data.table(cbind(dataset[,c("Y","w","gps",
+                                                 "counter","row_index")],
                           ipw, dataset[,6:length(dataset)])))
 }
