@@ -50,6 +50,7 @@
 #'   - *covar_bl_method*: covariate balance method. Available options:
 #'      - 'absolute'
 #'   - *covar_bl_trs*: covariate balance threshold
+#'   - *covar_bl_trs_type*: covariate balance type (mean, median, maximal)
 #'   - *max_attempt*: maximum number of attempt to satisfy covariate balance.
 #'   - See [create_matching()] for more details about the parameters and default
 #'   values.
@@ -94,6 +95,7 @@
 #'                                   nthread = 1,
 #'                                   covar_bl_method = "absolute",
 #'                                   covar_bl_trs = 0.1,
+#'                                   covar_bl_trs_type= "mean",
 #'                                   max_attempt = 1,
 #'                                   matching_fun = "matching_l1",
 #'                                   delta_n = 1,
@@ -158,7 +160,6 @@ generate_pseudo_pop <- function(Y,
 
   tmp_data <- convert_data_into_standard_format(Y, w, c, q1, q2, ci_appr)
 
-
   original_corr_obj <- check_covar_balance(tmp_data, ci_appr, nthread,
                                            optimized_compile, ...)
   tmp_data <- NULL
@@ -244,6 +245,8 @@ generate_pseudo_pop <- function(Y,
 
     if (use_cov_transform){
 
+      logger::log_debug("------------ Started conducting covariate transform ...")
+
       sort_by_covar <- sort(adjusted_corr_obj$corr_results$absolute_corr,
                             decreasing = TRUE)
 
@@ -254,7 +257,8 @@ generate_pseudo_pop <- function(Y,
                                       function(x){ x[1] == c_name })))
 
         if (length(el_ind)==0){
-          # wants to choose a transformed column.
+          # wants to choose a transformed column, which indicates that the
+          # the transformation was not helpful. Move to the next worst covariate balance.
           next
         }
 
@@ -267,7 +271,15 @@ generate_pseudo_pop <- function(Y,
                           " Located at index {el_ind}.")
 
         for (operand in transformers){
-          if (!is.element(operand, transformed_vals[[el_ind]])){
+          if(length(transformed_vals[[el_ind]])>1){
+            if (!is.element(operand,
+                            transformed_vals[[el_ind]][2:length(transformed_vals[[el_ind]])])){
+                new_c <- c_name
+                new_op <- operand
+                value_found = TRUE
+                break
+            }
+          } else {
             new_c <- c_name
             new_op <- operand
             value_found = TRUE
@@ -279,7 +291,16 @@ generate_pseudo_pop <- function(Y,
 
       if (!value_found){
         warning(paste("All possible combination of transformers has been tried.",
-                      "Try using more transformers.", sep=" "))
+                      "Retrying ... .", sep=" "))
+
+        # removed used transformers on covariate balance.
+        transformed_vals <- covariate_cols
+        recent_swap <- NULL
+        if (sum(sort(colnames(c)) != sort(colnames(c_extended)))>0){
+          logger::log_error("At this step, c and c_extended should be the same, doublecheck.")
+          c_extended <- c
+        }
+        next
       } else {
 
       # add operand into the transformed_vals
@@ -295,6 +316,7 @@ generate_pseudo_pop <- function(Y,
       logger::log_debug("In the next iteration (if any) feature {c_name}",
                         " will be replaced by {unlist(colnames(t_dataframe))}.")
       }
+      logger::log_debug("------------ Finished conducting covariate transform.")
     }
   }
 
